package cn.iocoder.yudao.module.shipment.listener;


import cn.iocoder.yudao.framework.apollo.core.event.box.BoxOrderForceWarehouseCheckEvent;
import cn.iocoder.yudao.framework.apollo.core.event.box.BoxOrderRevokeWarehouseCheckEvent;
import cn.iocoder.yudao.module.shipment.dal.dataobject.BoxDO;
import cn.iocoder.yudao.module.shipment.dal.dataobject.BoxLoadInfoDO;
import cn.iocoder.yudao.module.shipment.service.box.BoxService;
import cn.iocoder.yudao.module.shipment.service.boxLoadInfo.BoxLoadInfoService;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.context.event.EventListener;
import org.springframework.stereotype.Component;

import java.util.Arrays;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.shipment.enums.ErrorCodeConstants.BOX_NOT_EXISTS;

/**
 * 订单撤销到仓业务执行
 *
 * @author zhengYi
 */
@Component("BoxOrderRevokeWarehouseCheckListener")
@AllArgsConstructor
@Slf4j
public class BoxOrderRevokeWarehouseCheckListener {

    private final BoxLoadInfoService boxLoadInfoService;
    private final BoxService boxService;


    /**
     * 订单强撤销到仓业务执行
     *
     * @param event 订单信息
     */
    @EventListener(BoxOrderRevokeWarehouseCheckEvent.class)
    public void orderForceWarehouseCheck(BoxOrderRevokeWarehouseCheckEvent event) {
        // 跟新卸柜/到仓箱标数据表未真实卸柜的箱标到仓时间为null
        boxLoadInfoService.update(new LambdaUpdateWrapper<BoxLoadInfoDO>()
                .set(BoxLoadInfoDO::getUnloadTime, null)
                .eq(BoxLoadInfoDO::getIsUnload, 0)
                .eq(BoxLoadInfoDO::getOrderId, event.getOrderId()));

    }


}
